# Reference

## inductance

```{eval-rst}
.. autosummary::
   :toctree: generated

.. automodule:: inductance
   :members:
```

### Coils

```{eval-rst}
.. automodule:: inductance.coils
   :members:
```

### Self inductance

```{eval-rst}
.. automodule:: inductance.self
   :members:
```

### Mutual inductance

```{eval-rst}
.. automodule:: inductance.mutual
   :members:
```

### elliptics

```{eval-rst}
.. automodule:: inductance.elliptics
   :members:
```

### filaments

```{eval-rst}
.. automodule:: inductance.filaments
   :members:
```
